#!/usr/bin/env python

##dateconfig - Program creates a user interface 
##             that allows the system time, system date,
##             time zone, and ntpd configuration to be easily set
## Copyright (C) 2001, 2002 Red Hat, Inc.
## Copyright (C) 2001, 2002 Brent Fox <bfox@redhat.com>
##                          Tammy Fox <tfox@redhat.com>

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#Originally Written by Brent Fox
#Created May 29, 2001
#Last Modified: Feb 13, 2002

import os
import time
import string

class dateBackend:
    def __init__(self):
        self.ntpFile = None
        self.ntpServer = None
        self.readNtpConf()
        pass

    def getDate (self):
        times = time.localtime(time.time())
        return times

    def writeDateConfig (self, sysDate, sysTime):
        year, month, day = sysDate
        hour, min, sec = sysTime

        #--cal.get_date starts counting months at 0 for Jan.  We need to start counting at 1
        month = month + 1
        path = '/bin/date -s %d/%d/%d' % (year,month,day)
        fd = os.popen(path, 'r')
        lines = fd.readlines()
        fd.close()

        path = '/bin/date -s %s:%s:%s' % (hour,min,sec)
        fd = os.popen(path, 'r')
        lines = fd.readlines()
        fd.close()


    def syncHardwareClock(self):
        # sync hardware clock.  Will use either localtime or utc
        # according to value in /etc/adjtime (recorded last time hwclock
        # was run).
        fd = os.popen("/sbin/hwclock --systohc", 'r')
        lines = fd.readlines()
        fd.close()

    def writeNtpConfig (self, timeServer):
        if self.ntpFile:
            fd = open("/etc/ntp.conf", "w")

            for line in self.ntpFile:
                location = string.find(line, 'server')

                #If "server" is found in the line
                if location == 0:
                    tokens = string.split(line)

                    #If the line doesn't begin with a '#', then we're good
                    if tokens[0][0] != "#" and tokens[0] == "server":
                        fd.write("server " + timeServer + "\n")
                    else:
                        #Else the line must either be a comment or some other abberation
                        #Just write the line so we preserve comments
                        fd.write(line)                        
                else:
                    fd.write(line)

    def startNtpService (self):
        path = ('/sbin/service ntpd restart')
        os.system (path)
        path = ('/sbin/chkconfig --level 35 ntpd on')
        os.system (path)
        
    def stopNtpService (self):
        path = ('/sbin/service ntpd stop')
        os.system (path)
        path = ('/sbin/chkconfig --level 35 ntpd off')
        os.system (path)
        
    def isNtpRunning (self):
        command = ('/sbin/service ntpd status')
        fd = os.popen(command, 'r')
        output = fd.readlines()
        fd.close()

        line = output[0]

        try:
            if string.index(line, "running") > -1:
                #ntpd is running
                return 1
        except:
            #ntpd is not running
            return 0

    def getNtpServer(self):
        if self.ntpFile:
            for line in self.ntpFile:
                location = string.find(line, 'server')

                if location == 0:
                    tokens = string.split(line)
                    
                    if tokens[0][0] != "#" and tokens[0] == "server":
                        if len(tokens) > 1 :
                            self.ntpServer = tokens[1]
                        else:
                            self.ntpServer = ""
            return self.ntpServer

    def readNtpConf(self):
        try:
            fd = open('/etc/ntp.conf', 'r')
            self.ntpFile = fd.readlines()
            fd.close()
        except:
            return

